/*
***********************************************************************
* COPYRIGHT AND (LACK OF) WARRANTY INFORMATION
*
* Copyright 2001-2005
* International Telecommunications Union, Geneva
*
* DISCLAIMER OF WARRANTY
*
* These software programs are available to the user without any
* license fee or royalty on an "as is" basis. The ITU disclaims
* any and all warranties, whether express, implied, or
* statutory, including any implied warranties of merchantability
* or of fitness for a particular purpose.  In no event shall the
* contributor or the ITU be liable for any incidental, punitive, or
* consequential damages of any kind whatsoever arising from the
* use of these programs.
*
* This disclaimer of warranty extends to the user of these programs
* and user's customers, employees, agents, transferees, successors,
* and assignees.
*
* The ITU does not represent or warrant that the programs furnished
* hereunder are free of infringement of any third-party patents.
* Commercial implementations of ITU-T Recommendations, including
* shareware, may be subject to royalty fees to patent holders.
* Information regarding the ITU-T patent policy is available from
* the ITU Web site at http://www.itu.int.
*
* THIS IS NOT A GRANT OF PATENT RIGHTS - SEE THE ITU-T PATENT POLICY.
************************************************************************
*/

 
/*!
 ************************************************************************
 * \file epzs.h
 *
 * \author
 *    Alexis Michael Tourapis        <alexismt@ieee.org>              
 *
 ************************************************************************
 */

#ifndef _EPZS_H_
#define _EPZS_H_


#define CHECK_RANGE  ((cand_x >= 0) && (cand_x < img_width  - blocksize_x) &&(cand_y >= 0) && (cand_y < img_height - blocksize_y)) 


typedef struct 
{
  int         mb_adaptive_frame_field_flag;
  int         size_x, size_y;

  // Frame
  short ****  mv;            //!< motion vector       [list][subblock_x][subblock_y][component]  
  // Top field
  short ****  top_mv;        //!< motion vector       [list][subblock_x][subblock_y][component]  
  // Bottom field params
  short ****  bottom_mv;     //!< motion vector       [list][subblock_x][subblock_y][component]   

} EPZSColocParams;

typedef struct
{
  int x;
  int y;
  int start_nmbr;
  int next_points;
}
SPoint;

typedef struct 
{
  int  searchPoints;
  SPoint *point;
}
EPZSStructure;

typedef enum
{
  SDIAMOND = 0,
  SQUARE   = 1,
  EDIAMOND = 2,
  LDIAMOND = 3
} EPZSPatterns;

extern EPZSColocParams *EPZSCo_located;
extern int ***EPZSDistortion;  //!< Array for storing SAD Values

extern int EPZSInit();
extern void EPZSDelete ();
extern void EPZSOutputStats(FILE *stat,short stats_file);
extern void EPZSSliceInit(EPZSColocParams* p, StorablePicture **listX[6]);
extern int EPZSPelBlockMotionSearch (pel_t **, short, int, int, char ***, short ****, 
                                     int, int, int, short, short, short*, short*, int, int, int);

extern int EPZSBiPredBlockMotionSearch (pel_t **,	short, int, int, char  ***, short  ****, 
                                        int, int, int, short, short, short, short, 
                                        short *, short *,	short *, short *, int, int, int);	     

#endif
